@@ -1,4 +1,7 @@
 
+#ifdef WIN32
+#include <stdlib.h>
+#endif
 #include "ConstrDestrCopyDialog.h"
 #include "UmlClass.h"
 
@@ -9,6 +12,7 @@
 #include <qlabel.h>
 #include <qhbox.h>
 #include <qvbox.h> 
+#include <qdir.h>
 ConstrDestrCopyDialog::ConstrDestrCopyDialog(UmlClass * cl, bool have_constructor,
                                   bool have_destructor, bool have_copy,
                                   bool have_const_copy, bool have_assignment,
@@ -175,6 +179,55 @@ ConstrDestrCopyDialog::ConstrDestrCopyDialog(UmlClass * cl, bool have_constructo
   connect(cancel, SIGNAL(clicked()), this, SLOT(reject()));
 }
 
+void ConstrDestrCopyDialog::polish() {
+  QDialog::polish();
+  
+  // try to read .boumlrc
+  // note : QFile fp(QDir::home().absFilePath(".boumlrc")) doesn't work
+  // if the path contains non latin1 characters, for instance cyrillic !
+  QString s = QDir::home().absFilePath(".boumlrc");
+  FILE * fp = fopen((const char *) s, "r");
+
+#ifdef WIN32
+  if (fp == 0) {
+    QString hd = getenv("USERPROFILE");
+    
+    if (! hd.isEmpty()) {
+      QDir d(hd);
+      QString s2 = d.absFilePath(".boumlrc");
+      
+      fp = fopen((const char *) s2, "r");
+    }
+  }
+#endif
+  
+  if (fp != 0) {
+    char line[512];
+      
+    while (fgets(line, sizeof(line) - 1, fp) != 0) {
+      if (!strncmp(line, "DESKTOP ", 8)) {
+	int l, t, r, b;
+	
+	if (sscanf(line+8, "%d %d %d %d", &l, &t, &r, &b) == 4) {
+	  if (!((r == 0) && (t == 0) && (r == 0) && (b == 0)) &&
+	      !((r < 0) || (t < 0) || (r < 0) || (b < 0)) &&
+	      !((r <= l) || (b <= t))) {
+	    int cx = (r + l) /2;
+	    int cy = (t + b) / 2;
+	    
+	    move(x() + cx - (x() + width() / 2), 
+		 y() + cy - (y() + height() / 2));
+	  }
+	}
+	  
+	break;
+      }
+    }
+    
+    fclose(fp);
+  }
+}
+
 void ConstrDestrCopyDialog::accept() {
   if (add_constr->isChecked())
     target->addContructor(constr_explicit->isChecked());
