@@ -10,11 +10,11 @@ class QCheckBox;
 //A dialog to set the check-in/out command and set the recursive flag
 
 class Dialog : public QDialog {
+  Q_OBJECT
+
   public:
     Dialog(bool ci, QCString & cmd, BooL & rec, BooL & reload);
 
-    virtual void accept();
-
 
   protected:
     QCString & _cmd;
@@ -29,6 +29,13 @@ class Dialog : public QDialog {
 
     QCheckBox * reload_cb;
 
+protected slots:
+    virtual void polish();
+
+
+  public:
+    virtual void accept();
+
 };
 
 #endif
