@@ -6,11 +6,24 @@
 #include <qstring.h>
 
 #include <qdialog.h>
+#include <qlineedit.h>
 
 class QLineEdit;
 class QRadioButton;
 class QCheckBox;
 
+class LineEdit : public QLineEdit {
+  public:
+    LineEdit(QWidget * parent);
+
+
+  protected:
+    bool focusNextPrevChild(bool next);
+
+    void keyPressEvent(QKeyEvent * e);
+
+};
+
 class Dialog : public QDialog {
 Q_OBJECT
   public:
@@ -58,6 +71,8 @@ Q_OBJECT
 
     QCheckBox * php_cb;
 
+    QCheckBox * python_cb;
+
     QCheckBox * idl_cb;
 
     QLineEdit * current_le;
