@@ -44,33 +44,34 @@ void UmlActivityObject::html_internal(QCString pfix, unsigned int rank, unsigned
     fw.write("</p>");
   }
 
-  fw.write("<p>Selection :</p><ul>");
-  
   s = selection();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>OCL : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
+  
+  QCString scpp = cppSelection();
+  QCString sjava = javaSelection();
+  
+  if (!s.isEmpty() || !scpp.isEmpty() || !sjava.isEmpty()) {
+    fw.write("<p>Selection :</p><ul>");
+  
+    if (!s.isEmpty()) {
+      fw.write("<li>OCL : <pre>\n");
+      writeq(s);
+      fw.write("</pre></li>");
+    }
+    
+    if (!scpp.isEmpty()) {
+      fw.write("<li>C++ : <pre>\n");
+      writeq(scpp);
+      fw.write("</pre></li>");
+    }
+    
+    if (!sjava.isEmpty()) {
+      fw.write("<li>Java : <pre>\n");
+      writeq(sjava);
+      fw.write("</pre></li>");
+    }
+    
+    fw.write("</ul>");
   }
-
-  s = cppSelection();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>C++ : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
-  }
-
-  s = javaSelection();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>Java : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
-  }
-
-  fw.write("</ul>");
   
   if (ordering() != unordered) {
     fw.write("<p>Ordering : ");
