@@ -106,42 +106,47 @@ void UmlClass::gen_html(QCString pfix, unsigned int rank, unsigned int level) {
       gen_cpp_decl(s, TRUE);
     fw.write("<br /></p>\n");
   }
-  
-  fw.write("<p>Declaration :</p><ul>\n");
-  
-  s = cppDecl();
 
-  if (!s.isEmpty()) {
-    fw.write("<li>C++ : ");
-    gen_cpp_decl(s, FALSE);
-    fw.write("</li>");
+  if (!cppDecl().isEmpty() ||
+      !javaDecl().isEmpty() ||
+      !phpDecl().isEmpty() ||
+      !pythonDecl().isEmpty()) {
+    fw.write("<p>Declaration :</p><ul>\n");
+    
+    s = cppDecl();
+    
+    if (!s.isEmpty()) {
+      fw.write("<li>C++ : ");
+      gen_cpp_decl(s, FALSE);
+      fw.write("</li>");
+    }
+    
+    s = javaDecl();
+    
+    if (!s.isEmpty()) {
+      fw.write("<li>Java : ");
+      gen_java_decl(s, FALSE);
+      fw.write("</li>");
+    }
+    
+    s = phpDecl();
+    
+    if (!s.isEmpty()) {
+      fw.write("<li>Php : ");
+      gen_php_decl(s, FALSE);
+      fw.write("</li>");
+    }
+    
+    s = pythonDecl();
+    
+    if (!s.isEmpty()) {
+      fw.write("<li>Python : ");
+      gen_python_decl(s, FALSE);
+      fw.write("</li>");
+    }
+    
+    fw.write("</ul>");
   }
-
-  s = javaDecl();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>Java : ");
-    gen_java_decl(s, FALSE);
-    fw.write("</li>");
-  }
-
-  s = phpDecl();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>Php : ");
-    gen_php_decl(s, FALSE);
-    fw.write("</li>");
-  }
-
-  s = pythonDecl();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>Python : ");
-    gen_python_decl(s, FALSE);
-    fw.write("</li>");
-  }
-
-  fw.write("</ul>");
   
   if (subClasses.size() != 0) {
     sort(subClasses);
@@ -209,54 +214,63 @@ void UmlClass::gen_html(QCString pfix, unsigned int rank, unsigned int level) {
   const QVector<UmlItem> ch = children();
   
   if (ch.size() != 0) {
-    fw.write("<div class=\"sub\">\n");
-    
     if (stereotype() == "enum_pattern") {
-
-      fw.write("<p>Items :</p><ul>\n");
-      
+      p = FALSE;
+            
       for (unsigned i = 0; i != ch.size(); i += 1) {
 	if (ch[i]->kind() == anAttribute) {
+	  if (!p) {
+	    p = TRUE;
+	    fw.write("<div class=\"sub\">\n<p>Items :</p><ul>\n");
+	  }
 	  fw.write("<li>");
 	  writeq(ch[i]->name());
 	  fw.write("</li>\n");
 	}
       }
-      
-      fw.write("</ul>\n");
+      if (p)
+	fw.write("</ul>\n</div>\n");
     }
-    else if (stereotype() == "enum") {
-      unsigned i;
-
-      fw.write("<p>Items :</p><ul>\n");
-      
-      for (i = 0; i != ch.size(); i += 1) {
-	if ((ch[i]->kind() == anAttribute) &&
-	    (ch[i]->stereotype() != "attribute")) {
-	  fw.write("<li>");
-	  writeq(ch[i]->name());
-	  fw.write("</li>\n");
-	}
-      }
-      
-      fw.write("</ul>\n");
-      
-      s = "";
-      for (i = 0; i != ch.size(); i += 1)
-	if ((ch[i]->kind() != anAttribute) ||
-	    (ch[i]->stereotype() == "attribute"))
-	  ch[i]->html(s, 0, 0);
-    }
-    else if (flat)
-      write_children(pfix, rank, level);
     else {
-      // non flat
-      s = "";
-      for (unsigned i = 0; i != ch.size(); i += 1)
-	ch[i]->html(s, 0, 0);
+      fw.write("<div class=\"sub\">\n");
+      
+      if (stereotype() == "enum") {
+	unsigned i;
+	
+	p = FALSE;
+	
+	for (i = 0; i != ch.size(); i += 1) {
+	  if ((ch[i]->kind() == anAttribute) &&
+	      (ch[i]->stereotype() != "attribute")) {
+	    if (!p) {
+	      p = TRUE;
+	      fw.write("<p>Items :</p><ul>\n");
+	    }
+	    fw.write("<li>");
+	    writeq(ch[i]->name());
+	    fw.write("</li>\n");
+	  }
+	}
+	if (p)
+	  fw.write("</ul>\n");
+	
+	s = "";
+	for (i = 0; i != ch.size(); i += 1)
+	  if ((ch[i]->kind() != anAttribute) ||
+	      (ch[i]->stereotype() == "attribute"))
+	    ch[i]->html(s, 0, 0);
+      }
+      else if (flat)
+	write_children(pfix, rank, level);
+      else {
+	// non flat
+	s = "";
+	for (unsigned i = 0; i != ch.size(); i += 1)
+	  ch[i]->html(s, 0, 0);
+      }
+      
+      fw.write("</div>\n");
     }
-    
-    fw.write("</div>\n");
   }
 
   sort(*inherited_opers);
@@ -342,7 +356,7 @@ void UmlClass::generate_index()
   
   start_file("classes_list", "Classes", FALSE);
   
-  fw.write("<table border=\"0\" width=\"100%\">\n<tr>\n<td nowrap>");
+  fw.write("<table border=\"0\" width=\"100%\">\n<tr>\n<td nowrap=\"nowrap\">");
   
   for (int i = 0; i != n; i += 1) {
     classes.elementAt(i)->write("projectFrame");
