@@ -101,12 +101,12 @@ void UmlOperation::generate_index()
     start_file("public_operations", "Public Operations Index", TRUE);
     
     fw.write("<table>\n");
-    fw.write("<tr bgcolor=#f0f0f0><td align=center><b>Operation</b></td><td align=center><b>Class</b></td><td align=center><b>Description</b></td></tr>\n");
+    fw.write("<tr bgcolor=\"#f0f0f0\"><td align=\"center\"><b>Operation</b></td><td align=\"center\"><b>Class</b></td><td align=\"center\"><b>Description</b></td></tr>\n");
       
     for (unsigned i = 0; i != n; i += 1) {
       UmlItem * op = opers.elementAt(i);
       
-      fw.write("<tr bgcolor=#f0f0f0><td>");
+      fw.write("<tr bgcolor=\"#f0f0f0\"><td>");
       op->write();
       fw.write("</td><td>");
       op->parent()->write();
