@@ -25,34 +25,35 @@ void UmlStateAction::html(QCString pfix, unsigned int rank, unsigned int level)
     parent()->write();
   fw.write("</p>");
 
-  fw.write("<p>Expression :</p><ul>");
-  
   s = expression();
+  
+  QCString scpp = cppExpression();
+  QCString sjava = javaExpression();
 
-  if (!s.isEmpty()) {
-    fw.write("<li>OCL : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
+  if ((!s.isEmpty()) || (!scpp.isEmpty()) || (!sjava.isEmpty())) {
+    fw.write("<p>Expression :</p><ul>");
+  
+    if (!s.isEmpty()) {
+      fw.write("<li>OCL : <pre>\n");
+      writeq(s);
+      fw.write("</pre></li>");
+    }
+    
+    if (!scpp.isEmpty()) {
+      fw.write("<li>C++ : <pre>\n");
+      writeq(scpp);
+      fw.write("</pre></li>");
+    }
+    
+    if (!sjava.isEmpty()) {
+      fw.write("<li>Java : <pre>\n");
+      writeq(sjava);
+      fw.write("</pre></li>");
+    }
+    
+    fw.write("</ul>");
   }
 
-  s = cppExpression();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>C++ : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
-  }
-
-  s = javaExpression();
-
-  if (!s.isEmpty()) {
-    fw.write("<li>Java : <pre>\n");
-    writeq(s);
-    fw.write("</pre></li>");
-  }
-
-  fw.write("</ul>");
-
   write_children(pfix, rank, level);
 
   unload(FALSE, FALSE);
