@@ -7,6 +7,7 @@
 void UmlState::write(FileOut & out) {
   anItemKind pkind = parent()->kind();
   bool mach = (pkind != aState) && (pkind != aRegion);
+  UmlState * ref = reference();
   const char * k;
   
   if (mach) {
@@ -24,76 +25,82 @@ void UmlState::write(FileOut & out) {
   out << " name=\"";
   out.quote(name());
   out << '"';
-  if (specification() != 0)
-    out.ref(specification(), "specification");
-  if (isActive())
-    out << " isActive=\"true\"";
+  if (ref != 0)
+    out.ref(ref, "submachine");
+  else {
+    if (specification() != 0)
+      out.ref(specification(), "specification");
+    if (isActive())
+      out << " isActive=\"true\"";
+  }
   out << ">\n";
   out.indent(+1); 
   
   write_description_properties(out); 
   
-  QCString doentry;
-  QCString doactivity;
-  QCString doexit;
-  
-  switch (_lang) {
-  case Uml:
-    doentry = entryBehavior();
-    doactivity = doActivity();
-    doexit = exitBehavior();
-    break;
-  case Cpp:
-    doentry = cppEntryBehavior();
-    doactivity = cppDoActivity();
-    doexit = cppExitBehavior();
-    break;
-  default: // Java
-    doentry = javaEntryBehavior();
-    doactivity = javaDoActivity();
-    doexit = javaExitBehavior();
-    break;
+  if (ref == 0) {
+    QCString doentry;
+    QCString doactivity;
+    QCString doexit;
+    
+    switch (_lang) {
+    case Uml:
+      doentry = entryBehavior();
+      doactivity = doActivity();
+      doexit = exitBehavior();
+      break;
+    case Cpp:
+      doentry = cppEntryBehavior();
+      doactivity = cppDoActivity();
+      doexit = cppExitBehavior();
+      break;
+    default: // Java
+      doentry = javaEntryBehavior();
+      doactivity = javaDoActivity();
+      doexit = javaExitBehavior();
+      break;
+    }
+    
+    if (! doentry.isEmpty()) {
+      out.indent();
+      out << "<entry xmi:type=\"uml:Activity\"";
+      out.id_prefix(this, "ENTRY_");
+      out << ">\n";
+      out.indent();
+      out << "\t<body>";
+      out.quote(doentry);
+      out << "</body>\n";
+      out.indent();
+      out << "</entry>\n";
+    }
+    
+    if (! doactivity.isEmpty()) {
+      out.indent();
+      out << "<doActivity xmi:type=\"uml:Activity\"";
+      out.id_prefix(this, "DOACTIVITY_");
+      out << ">\n";
+      out.indent();
+      out << "\t<body>";
+      out.quote(doactivity);
+      out << "</body>\n";
+      out.indent();
+      out << "</doActivity>\n";
+    }
+    
+    if (! doexit.isEmpty()) {
+      out.indent();
+      out << "<exit xmi:type=\"uml:Activity\"";
+      out.id_prefix(this, "EXIT_");
+      out << ">\n";
+      out.indent();
+      out << "\t<body>";
+      out.quote(doexit);
+      out << "</body>\n";
+      out.indent();
+      out << "</exit>\n";
+    }
   }
   
-  if (! doentry.isEmpty()) {
-    out.indent();
-    out << "<entry xmi:type=\"uml:Activity\"";
-    out.id_prefix(this, "ENTRY_");
-    out << ">\n";
-    out.indent();
-    out << "\t<body>";
-    out.quote(doentry);
-    out << "</body>\n";
-    out.indent();
-    out << "</entry>\n";
-  }
-  
-  if (! doactivity.isEmpty()) {
-    out.indent();
-    out << "<doActivity xmi:type=\"uml:Activity\"";
-    out.id_prefix(this, "DOACTIVITY_");
-    out << ">\n";
-    out.indent();
-    out << "\t<body>";
-    out.quote(doactivity);
-    out << "</body>\n";
-    out.indent();
-    out << "</doActivity>\n";
-  }
-  
-  if (! doexit.isEmpty()) {
-    out.indent();
-    out << "<exit xmi:type=\"uml:Activity\"";
-    out.id_prefix(this, "EXIT_");
-    out << ">\n";
-    out.indent();
-    out << "\t<body>";
-    out.quote(doexit);
-    out << "</body>\n";
-    out.indent();
-    out << "</exit>\n";
-  }
-     
   while (! _incoming_trans.isEmpty())
     _incoming_trans.take(0)->write_in(out);
   
@@ -110,11 +117,13 @@ void UmlState::write(FileOut & out) {
   }
 
   if (need_region) {
-    out.indent();
-    out << "<region xmi:type=\"uml:Region\"";
-    out.id_prefix(this, "IMPLICIT_REGION_");
-    out << " name=\"Bouml_Implicit_Region\">\n";
-    out.indent(+1);
+    if (ref == 0) {
+      out.indent();
+      out << "<region xmi:type=\"uml:Region\"";
+      out.id_prefix(this, "IMPLICIT_REGION_");
+      out << " name=\"Bouml_Implicit_Region\">\n";
+      out.indent(+1);
+    }
     
     for (i = 0; i != n; i += 1)
       if (ch[i]->kind() != aRegion)
@@ -126,14 +135,18 @@ void UmlState::write(FileOut & out) {
       _trans.take(0)->write_it(out);
 #endif
     
-    out.indent(-1);
-    out.indent();
-    out << "</region>\n";
+    if (ref == 0) {
+      out.indent(-1);
+      out.indent();
+      out << "</region>\n";
+    }
   }
 
-  for (i = 0; i != n; i += 1)
-    if (ch[i]->kind() == aRegion)
-      ch[i]->write(out);
+  if (ref == 0) {
+    for (i = 0; i != n; i += 1)
+      if (ch[i]->kind() == aRegion)
+	ch[i]->write(out);
+  }
        
 #if 1
     // to bypass Eclipse's bug
