@@ -5,9 +5,6 @@
 #include <qcstring.h>
 #include "UmlBaseClassMember.h"
 
-class FileIn;
-class Token;
-
 // This class globaly manages class's relations, attributes, operations 
 // and sub-classes
 //
@@ -18,8 +15,6 @@ class UmlClassMember : public UmlBaseClassMember {
 
     void setVisibility(QCString v);
 
-    static QCString readConstraint(FileIn & in, Token & token);
-
 };
 
 #endif
