@@ -28,7 +28,7 @@ bool UmlCom::connect(unsigned int port)
   
   if (sock->connect(ha, port)) {
     // send API version
-    write_unsigned(48);
+    write_unsigned(55);
     flush();
     return TRUE;
   }
@@ -62,9 +62,9 @@ void UmlCom::message(const char * s)
   send_cmd(miscGlobalCmd, messageCmd, s);
 }
 
-void UmlCom::bye()
+void UmlCom::bye(int v)
 {
-  send_cmd(miscGlobalCmd, byeCmd);
+  send_cmd(miscGlobalCmd, byeCmd, v, "");
 }
 
 void UmlCom::close()
