@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyright 2004-2009 Bruno PAGES  .
+// Copyright 2004-2010 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -26,7 +26,13 @@
 #include "UmlPackage.h"
 #include "UmlClassView.h"
 #include "UmlArtifact.h"
+#ifdef REVERSE
 #include "UmlDeploymentView.h"
+# ifdef ROUNDTRIP
+# include "Package.h"
+# include "Progress.h"
+# endif
+#endif
 #include "UmlOperation.h"
 #include "Lex.h"
 #include "UmlCom.h"
@@ -36,6 +42,9 @@ UmlPackage::UmlPackage(void * id, const QCString & n)
   class_view = 0;
 #ifdef REVERSE
   deployment_view = 0;
+# ifdef ROUNDTRIP
+  package = 0;
+# endif
 #endif
   namespace_fixedp = FALSE;
 }
@@ -58,6 +67,9 @@ UmlClassView * UmlPackage::get_classview(const QCString & nmsp) {
 	}
 	
 	if (((pack = UmlBasePackage::create(this, s)) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
 	    ((pack = UmlBasePackage::create(this, s += "_")) == 0)) {
 #ifdef REVERSE
 	  UmlCom::trace(QCString("<font face=helvetica><b>cannot create package <i>")
@@ -75,6 +87,8 @@ UmlClassView * UmlPackage::get_classview(const QCString & nmsp) {
 	}
 	
 	pack->set_CppNamespace(nmsp);
+	pack->set_CppSrcDir(cppSrcDir());
+	pack->set_CppHDir(cppHDir());
 	pack->namespace_fixedp = TRUE;
       }
     }
@@ -124,31 +138,49 @@ void UmlPackage::reverse_main(const QCString & type, QCString comment) {
   
   UmlArtifact * cp;
   
-  if ((cp = UmlBaseArtifact::create(get_deploymentview(0), "main")) == 0)
-    UmlCom::trace("<font face=helvetica><b>cannot create <i>artifact main</i></b></font><br><hr>");
-  else {
-    cp->set_Stereotype("source");
-
-    if (! comment.isEmpty()) {
-      unsigned start = 0;
-      
-      do {
-	comment.insert(start, "//");
-	start = comment.find('\n', start + 2) + 1;
-      } while (start != 0);
-      comment.append("\n\n");
-    }
-    
-    comment.append(type);
-    comment.append(" main(");
-    comment.append(Lex::region());
-    comment.append("\n");
-    
-    cp->set_CppSource(comment);
-    cp->set_CppHeader(0);
+#ifdef ROUNDTRIP
+  bool roundtrip = FALSE;
+  
+  if ((cp = UmlArtifact::get_main()) != 0) {
+    roundtrip = TRUE;
+    cp->set_usefull();
   }
+  else
+#endif
+  if ((cp = UmlBaseArtifact::create(get_deploymentview(0), "main")) == 0) {
+    UmlCom::trace("<font face=helvetica><b>cannot create <i>artifact main</i></b></font><br><hr>");
+    return;
+  }
+  
+  if (! comment.isEmpty()) {
+    unsigned start = 0;
+    
+    do {
+      comment.insert(start, "//");
+      start = comment.find('\n', start + 2) + 1;
+    } while (start != 0);
+    comment.append("\n\n");
+  }
+  
+  comment.append(type);
+  comment.append(" main(");
+  comment.append(Lex::region());
+  comment.append("\n");
+  
+#ifdef ROUNDTRIP
+  if (roundtrip) {
+    if (cp->cppSource() != comment)
+      cp->set_CppSource(comment);
+    return;
+  }
+#endif
+  
+  cp->set_Stereotype("source");
+  cp->set_CppSource(comment);
+  cp->set_CppHeader(0);
 }
 
+
 UmlDeploymentView * UmlPackage::get_deploymentview(const QCString & nmsp) {
   UmlPackage * pack;
   
@@ -167,6 +199,9 @@ UmlDeploymentView * UmlPackage::get_deploymentview(const QCString & nmsp) {
 	}
 	
 	if (((pack = UmlBasePackage::create(this, s)) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
+	    ((pack = UmlBasePackage::create(this, s += "_")) == 0) &&
 	    ((pack = UmlBasePackage::create(this, s += "_")) == 0)) {
 #ifdef REVERSE
 	  UmlCom::trace(QCString("<font face=helvetica><b>cannot create package <i>")
@@ -184,6 +219,8 @@ UmlDeploymentView * UmlPackage::get_deploymentview(const QCString & nmsp) {
 	}
 	
 	pack->set_CppNamespace(nmsp);
+	pack->set_CppSrcDir(cppSrcDir());
+	pack->set_CppHDir(cppHDir());
 	pack->namespace_fixedp = TRUE;
       }
     }
@@ -224,5 +261,81 @@ UmlDeploymentView * UmlPackage::get_deploymentview(const QCString & nmsp) {
   return pack->deployment_view;
 }
 
+# ifdef ROUNDTRIP
+
+// applied on the project
+void UmlPackage::init(Package * p) {
+  package = p;
+  
+  const QVector<UmlItem> & ch = UmlItem::children();
+  UmlItem ** v = ch.data();
+  UmlItem ** const vsup = v + ch.size();
+    
+  for (;v != vsup; v += 1)
+    (*v)->upload(package);
+}
+
+void UmlPackage::upload(ClassContainer * cnt) {
+  package = new Package((Package *) cnt, this);
+  
+  const QVector<UmlItem> & ch = UmlItem::children();
+  UmlItem ** v = ch.data();
+  UmlItem ** const vsup = v + ch.size();
+    
+  for (;v != vsup; v += 1)
+    (*v)->upload(package);
+}
+
+int UmlPackage::count_roundtriped() {
+  int result = 1;
+  
+  const QVector<UmlItem> & ch = UmlItem::children();
+  UmlItem ** v = ch.data();
+  UmlItem ** const vsup = v + ch.size();
+    
+  for (;v != vsup; v += 1)
+    if ((*v)->kind() == aPackage)
+      result += ((UmlPackage *) *v)->count_roundtriped();
+  
+  return result;
+}
+
+bool UmlPackage::set_roundtrip_expected() {
+  if (cppHDir().isEmpty())
+    package->accept_roundtrip_root(TRUE);
+  if (cppSrcDir().isEmpty())
+    package->accept_roundtrip_root(FALSE);
+  
+  Progress::tic_it();
+  
+  const QVector<UmlItem> & ch = UmlItem::children();
+  UmlItem ** v = ch.data();
+  UmlItem ** const vsup = v + ch.size();
+  bool result = isWritable();
+    
+  for (;v != vsup; v += 1)
+    result &= (*v)->set_roundtrip_expected();
+  
+  return result;
+}
+
+void UmlPackage::mark_useless(QList<UmlItem> & l) {
+  QVector<UmlItem> ch = UmlItem::children();
+  UmlClassItem ** v = (UmlClassItem **) ch.data();
+  UmlClassItem ** const vsup = v + ch.size();
+    
+  for (;v != vsup; v += 1)
+    (*v)->mark_useless(l);
+}
+
+void UmlPackage::scan_it(int & n) {
+  package->scan_dir(n);
+}
+
+void UmlPackage::send_it(int n) {
+  package->send_dir(n);
+}
+
+# endif
 #endif
 
