@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyright 2004-2009 Bruno PAGES  .
+// Copyright 2004-2010 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -38,7 +38,7 @@ class UmlRelation : public UmlBaseRelation {
     };
   
     void generate_inherit(const char *& sep, QTextOStream & f, 
-			  const QCString & cl_stereotype, bool & already);
+			  const QCString & cl_stereotype, BooL & already);
     virtual void generate_decl(QTextOStream & f, const QCString & cl_stereotype,
 			       QCString indent, bool = FALSE);
 };
