@@ -3,6 +3,7 @@
 
 
 #include "UmlPseudoState.h"
+#include "anItemKind.h"
 #include <qcstring.h>
 
 class UmlEntryPointPseudoState;
@@ -23,9 +24,8 @@ class UmlBaseEntryPointPseudoState : public UmlPseudoState {
 
   protected:
     //  the constructor, do not call it yourself !!!!!!!!!!
-     UmlBaseEntryPointPseudoState(void * id, const QCString & s) : UmlPseudoState(id, s) {
-    }
-
+    UmlBaseEntryPointPseudoState(void * id, const QCString & s) : UmlPseudoState(id, s) {}
+    virtual void read_uml_();
 };
 
 #endif
