@@ -3,6 +3,7 @@
 
 
 #include "UmlPseudoState.h"
+#include "anItemKind.h"
 #include <qcstring.h>
 
 class UmlExitPointPseudoState;
@@ -23,9 +24,8 @@ class UmlBaseExitPointPseudoState : public UmlPseudoState {
 
   protected:
     //  the constructor, do not call it yourself !!!!!!!!!!
-     UmlBaseExitPointPseudoState(void * id, const QCString & s) : UmlPseudoState(id, s) {
-    }
-
+    UmlBaseExitPointPseudoState(void * id, const QCString & s) : UmlPseudoState(id, s) {}
+    virtual void read_uml_();
 };
 
 #endif
