@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyright 2004-2009 Bruno PAGES  .
+// Copyright 2004-2010 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -95,17 +95,19 @@ class BrowserClass : public BrowserNode, public Labeled<BrowserClass> {
     virtual void delete_it();
     virtual bool undelete(bool rec, QString & warning, QString & renamed);
     virtual bool may_contains_them(const QList<BrowserNode> &,
-				   bool & duplicable) const;
+				   BooL & duplicable) const;
     virtual void move(BrowserNode *, BrowserNode * after);
     virtual BrowserNode * duplicate(BrowserNode * p,
 				    QString name = QString::null);
     virtual QString full_name(bool rev = FALSE, bool itself = TRUE) const;
+    QString contextual_name(ShowContextMode) const;
     virtual void set_name(const char * s);
     virtual void member_cpp_def(const QString &, const QString &, QString & s, bool) const;
     virtual void menu();
     virtual void apply_shortcut(QString s);
     virtual void open(bool force_edit);
     virtual UmlCode get_type() const;
+    virtual QString get_stype() const;
     virtual int get_identifier() const;
     virtual const char * help_topic() const;
     virtual void modified();
